<template>
  <div :class="className" :style="{ height: height, width: width }" />
</template>

<script>
import echarts from 'echarts'
require('echarts/theme/macarons') // echarts theme
import resize from './mixins/resize'

export default {
  mixins: [resize],
  props: {
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '700px'
    },
    autoResize: {
      type: Boolean,
      default: true
    },
    chartData: {
      type: Object,
      required: true
    }
  },
  data() {
    return {
      chart: null
    }
  },
  watch: {
    chartData: {
      deep: true,
      handler(val) {
        this.setOptions(val)
      }
    }
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart()
    })
  },
  beforeDestroy() {
    if (!this.chart) {
      return
    }
    this.chart.dispose()
    this.chart = null
  },
  methods: {
    initChart() {
      this.chart = echarts.init(this.$el, 'macarons')
      this.setOptions(this.chartData)
    },
    setOptions({ ed, hd, nd, x } = {}) {
      this.chart.setOption({
        xAxis: {
          data: x,
          boundaryGap: false,
          type: 'category',
        },
        grid: {
          left: 10,
          right: 10,
          bottom: 20,
          top: 30,
          containLabel: true
        },
        tooltip: {
          trigger: 'axis',
        },
        yAxis: {
          type: 'value',
          max: function (value) {
            return value.max + 30
          },
          min: function (value) {
            return value.min - 30
          },
          name: '/毫米',
          splitLine:false
        },
        legend: {
          data: ['东位移', '北位移', '天位移'],
          textStyle: {
            color: '#1890ff' // 标题文字颜色
          },
        },
        series: [{
          name: '东位移',
          type: 'line',
          data: ed,
          smooth: false
        },
        {
          name: '北位移',
          type: 'line',
          data: nd,
          smooth: false
        }, {
          name: '天位移',
          type: 'line',
          data: hd,
          smooth: false
        }]
      })
    }
  }
}
</script>
